import { IConnectable, ISecurityGroup } from '@aws-cdk/aws-ec2';
import { ISecretAttachmentTarget } from '@aws-cdk/aws-secretsmanager';
import { IResource } from '@aws-cdk/core';
import { Endpoint } from './endpoint';
/**
 * Create a clustered database with a given number of instances.
 *
 * @stability stable
 */
export interface IDatabaseCluster extends IResource, IConnectable, ISecretAttachmentTarget {
    /**
     * Identifier of the cluster.
     *
     * @stability stable
     */
    readonly clusterIdentifier: string;
    /**
     * Identifiers of the replicas.
     *
     * @stability stable
     */
    readonly instanceIdentifiers: string[];
    /**
     * The endpoint to use for read/write operations.
     *
     * @stability stable
     * @attribute Endpoint,Port
     */
    readonly clusterEndpoint: Endpoint;
    /**
     * Endpoint to use for load-balanced read-only operations.
     *
     * @stability stable
     * @attribute ReadEndpoint
     */
    readonly clusterReadEndpoint: Endpoint;
    /**
     * Endpoints which address each individual replica.
     *
     * @stability stable
     */
    readonly instanceEndpoints: Endpoint[];
    /**
     * The security group for this database cluster.
     *
     * @stability stable
     */
    readonly securityGroupId: string;
}
/**
 * Properties that describe an existing cluster instance.
 *
 * @stability stable
 */
export interface DatabaseClusterAttributes {
    /**
     * The database port.
     *
     * @stability stable
     */
    readonly port: number;
    /**
     * The security group of the database cluster.
     *
     * @stability stable
     */
    readonly securityGroup: ISecurityGroup;
    /**
     * Identifier for the cluster.
     *
     * @stability stable
     */
    readonly clusterIdentifier: string;
    /**
     * Identifier for the instances.
     *
     * @stability stable
     */
    readonly instanceIdentifiers: string[];
    /**
     * Cluster endpoint address.
     *
     * @stability stable
     */
    readonly clusterEndpointAddress: string;
    /**
     * Reader endpoint address.
     *
     * @stability stable
     */
    readonly readerEndpointAddress: string;
    /**
     * Endpoint addresses of individual instances.
     *
     * @stability stable
     */
    readonly instanceEndpointAddresses: string[];
}
